@@ -35,12 +35,15 @@ pub static DEFAULT_BINDINGS_CONFIG: ResourceFile = ResourceFile {
     content: include_str!("../rc/default_bindings.pepper"),
 };
 
-static HELP_PAGES: HelpPages = HelpPages::new(&[]);
+static HELP_PAGES: HelpPages = HelpPages::new(&[ResourceFile {
+    name: "lsp_help.md",
+    content: include_str!("../rc/help.md"),
+}]);
 pub static DEFINITION: PluginDefinition = PluginDefinition {
     instantiate: |handle, ctx| {
         command::register_commands(&mut ctx.editor.commands, handle);
         Some(Plugin {
-            data: Box::new(LspPlugin::new()),
+            data: Box::new(LspPlugin::default()),
             on_editor_events,
             on_process_spawned,
             on_process_output,
@@ -99,7 +102,8 @@ impl Drop for ClientGuard {
     }
 }
 
-pub struct LspPlugin {
+#[derive(Default)]
+pub(crate) struct LspPlugin {
     entries: Vec<ClientEntry>,
     recipes: Vec<ClientRecipe>,
     read_line_client_handle: Option<ClientHandle>,
@@ -107,15 +111,6 @@ pub struct LspPlugin {
 }
 
 impl LspPlugin {
-    pub fn new() -> Self {
-        Self {
-            entries: Vec::new(),
-            recipes: Vec::new(),
-            read_line_client_handle: None,
-            picker_client_handle: None,
-        }
-    }
-
     pub fn add_recipe(
         &mut self,
         glob: &str,
@@ -266,13 +261,6 @@ impl LspPlugin {
             }
         }
     }
-
-    pub fn clients(&self) -> impl DoubleEndedIterator<Item = &Client> {
-        self.entries.iter().flat_map(|e| match e {
-            ClientEntry::Occupied(c) => Some(c.deref()),
-            _ => None,
-        })
-    }
 }
 
 fn on_editor_events(plugin_handle: PluginHandle, ctx: &mut EditorContext) {
@@ -478,8 +466,9 @@ fn on_completion(
                     );
                     let client_handle = client.handle();
                     lsp.on_client_operation(client_handle, op);
-                    return true;
+                    return false;
                 }
+
                 should_complete = client.completion_triggers().contains(c);
             }
         }
@@ -500,3 +489,4 @@ fn on_completion(
 
     false
 }
+
